==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Input/ffap/translations/ffap_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>Модуль FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Файли Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="150"/>
        <source>About FFap Audio Plugin</source>
        <translation>Про аудіо-модуль FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="151"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Аудіо-модуль FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="152"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Цей модуль додає підтримку Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Засновано на вихідному коді проектів deadbeef, FFmpeg та rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="65"/>
        <source>Samples</source>
        <translation>Семпли</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="66"/>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack_2.2.2.orig.tar.bz2: qmmp-plugin-pack-2.2.2/src/Input/ffap/translations/ffap_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>Втулок FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Файли Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="150"/>
        <source>About FFap Audio Plugin</source>
        <translation>Про авдіовтулок FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="151"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Авдіовтулок FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="152"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Цей втулок додає підтримку Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Засновано на джерельному коді проєктів deadbeef, FFmpeg і rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Samples</source>
        <translation>Семпли</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
</context>
</TS>
